@@ -164,6 +164,13 @@ def parse_args(argv, repoman_default_opts):
 			'A space separated list of arches used to '
 			'filter the selection of profiles for dependency checks'))
 
+	parser.add_argument(
+		'--include-profiles',
+		dest='include_profiles', metavar='PROFILES', action='append',
+		help=(
+			'A space separated list of profiles used to '
+			'define the selection of profiles for dependency checks'))
+
 	parser.add_argument(
 		'-d', '--include-dev', dest='include_dev', action='store_true',
 		default=False,
